#!/bin/bash
# Filename: spinbinmon.sh
# Author: Jesse Burt
# Created: Sep 15, 2018
# Updated: Sep 15, 2018
# Copyright (c) 2018
# See end of file for terms of use.

SELF=`basename $0`
WX_MODULE_IP=$1
BIN_MATCH=$2

function usage() {
  cat << EOF

    Utility that watches for the existence of a binary file matching a certain
    filename pattern, and when found, loads it wirelessly to a P8X32A/Propeller
    microcontroller.

    Requires:
      proploader (https://github.com/parallaxinc/PropLoader)
      A Propeller board with support for loading programs with a WX module
      A WX module

    Usage:
      $SELF <your_wx_module_ip> [pattern]

      your_wx_module_ip - Required - Should be self-explanatory
      pattern - Optional filename pattern this utility looks for to load to your
		Propeller. If not specified, it defaults to *.binary, i.e.,
		anything ending in .binary.

    Examples:
      $SELF 192.168.1.10 my_prop_program.binary
      $SELF 192.168.1.10 another_example.bin
      $SELF 192.168.1.10
EOF
  exit 1
}

# Validate args - IP is mandatory. Filename pattern is optional and defaults
# to *.binary if it isn't specified
if [ -z $WX_MODULE_IP ]; then usage; fi

# If pattern isn't specified, make it *.binary
if [ -z $BIN_MATCH ]; then BIN_MATCH="*.binary"; fi

echo "Watching for ${BIN_MATCH} to upload in ${PWD}..."

# Now, wait for that filename pattern to exist.
# If found, call proploader, and if successful, remove the binary right after.
# Wait 1 second in between checks.

while true; do
  if [ -r $BIN_MATCH ]; then
    proploader -i $WX_MODULE_IP $BIN_MATCH && \
    rm $BIN_MATCH
  fi
  sleep 1
done

# TERMS OF USE: MIT License

# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
# associated documentation files (the "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the
# following conditions:

# The above copyright notice and this permission notice shall be included in all copies or substantial
# portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
